==> lxqt-panel_1.1.0.orig.tar.xz: lxqt-panel-1.1.0/plugin-quicklaunch/translations/quicklaunch_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="224"/>
        <source>Drop Error</source>
        <translation>Bırakma Hatası</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="225"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Şimdilik &apos;%1&apos; dosyası/bağlantısı Hızlı Başlatıcı&apos; ya eklenemiyor</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="331"/>
        <source>Drop application
icons here</source>
        <translation>Uygulama simgesini
buraya bırakın</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + DND)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Sola kaydır</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Sağa kaydır</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="63"/>
        <source>Remove from quicklaunch</source>
        <translation>Hızlı başlatıcıdan kaldır</translation>
    </message>
</context>
</TS>

==> lxqt-panel_1.2.1.orig.tar.xz: lxqt-panel-1.2.1/plugin-quicklaunch/translations/quicklaunch_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="224"/>
        <source>Drop Error</source>
        <translation>Bırakma Hatası</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="225"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Şimdilik &apos;%1&apos; dosyası/bağlantısı Hızlı Başlatıcı&apos; ya eklenemiyor</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="331"/>
        <source>Drop application
icons here</source>
        <translation>Uygulama simgesini
buraya bırakın</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + DND)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Sola kaydır</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Sağa kaydır</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="63"/>
        <source>Remove from quicklaunch</source>
        <translation>Hızlı başlatıcıdan kaldır</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="72"/>
        <source>Refresh</source>
        <translation>Yenile</translation>
    </message>
</context>
</TS>
